@@ -10,4 +10,6 @@ if [ ! -d "${VENV}" ]; then
 fi
 
 "${VENV}/bin/python" -m pip install cfn-lint==0.75.0 --upgrade --quiet
+# update cfn schema
+"${VENV}/bin/cfn-lint" -u
 "${VENV}/bin/cfn-lint" --format parseable
