@@ -18,12 +18,7 @@ class RegionConfiguration:
         :return: True, if API Gateway does not support Edge configuration
         """
 
-        return ArnGenerator.get_partition_name() not in [
-            "aws-us-gov",
-            "aws-iso",
-            "aws-iso-b",
-            "aws-cn",
-        ]
+        return ArnGenerator.get_partition_name() not in ["aws-us-gov", "aws-iso", "aws-iso-b", "aws-cn", "aws-iso-e"]
 
     @classmethod
     def is_service_supported(cls, service, region=None):  # type: ignore[no-untyped-def]
@@ -38,7 +33,8 @@ class RegionConfiguration:
         :return: True, if the service is supported in the region
         """
 
-        session = boto3.Session()
+        # Attempt to re-use an existing session if present.
+        session = boto3.Session() if not boto3.DEFAULT_SESSION else boto3.DEFAULT_SESSION
 
         if not region:
             # get the current region
@@ -47,7 +43,7 @@ class RegionConfiguration:
             # need to handle when region is None so that it won't break
             if region is None:
                 if ArnGenerator.BOTO_SESSION_REGION_NAME is not None:
-                    region = ArnGenerator.BOTO_SESSION_REGION_NAME  # type: ignore[unreachable]
+                    region = ArnGenerator.BOTO_SESSION_REGION_NAME
                 else:
                     raise NoRegionFound("AWS Region cannot be found")
 
